% test objects for ao/whiten2D
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% DESCRIPTION: Output colored noise data and a model for mdc1 cross spectral density
% 
% CALL:
%       [CSD,a1,a2,a3,a4,a5,a6,av,am] = get_test_obj_ao_whiten2D()
% 
%
% OUTPUTS:
%              CSD     -  a 2x2 matrix of analysis objects containing CSD
%                       models
%              a#      -  are colored noise time series AOs
%              av      -  is a vector of 3 AOs
%              am      -  is a 2x2 matrix of AOs
% 
% M-FILE INFO: Get information about this methods by calling
%              >> ao.getInfo('get_test_obj_ao_whiten2D')
%
%              Get information about a specified set-plist by calling:
%              >> ao.getInfo('get_test_obj_ao_whiten2D', 'none')  
% 
% VERSION:     $Id: get_test_obj_ao_whiten2D.m,v 1.2 2009/02/19 17:34:18 luigi Exp $
%
% 
% HISTORY:     18-02-2009 L Ferraioli
%                 Creation
%
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [CSD,a1,a2,a3,a4,a5,a6,av,am,plstd] = get_test_obj_ao_whiten2D()
  
  % getting CSD and TF
  [CSD,TF,aw1,aw2,aw3,aw4,aw5,aw6,awv,awm,plstdng] = get_test_obj_ao_noisegen2D();
  
  % Generating test objects
  [a1,a2,a3,a4,a5,a6] = noisegen2D(aw1,aw2,aw3,aw4,aw5,aw6,plstdng);
  
  % setting name
  a1.setName;
  a2.setName;
  a3.setName;
  a4.setName;
  a5.setName;
  a6.setName;
  
  % Building vectors
  av = [a1 a2 a3];
  am = [a1 a3;a2 a4];
  
  fs = CSD(1,1).fs;
  % standrd plist for ao/whiten2D
  plstd = plist(...
    'csd11', CSD(1,1), ...
    'csd12', CSD(1,2), ...
    'csd21', CSD(2,1), ...
    'csd22', CSD(2,2), ...
    'MaxIter', 70, ...
    'PoleType', 2, ...
    'MinOrder', 24, ...
    'MaxOrder', 35, ...
    'Weights', 2, ...
    'Plot', false,...
    'FitTolerance', 1,...
    'RMSEVar', 5,...
    'UseSym', 0,...
    'Disp', false);
  

end